@@ -5,7 +5,7 @@
 
    Copyright (C) 1997-2005 Luke Howard
    Copyright (C) 2007 West Consulting
-   Copyright (C) 2007-2021 Arthur de Jong
+   Copyright (C) 2007-2025 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -685,7 +685,10 @@ static void handle_base(const char *filename, int lnr,
 #endif /* not HAVE_LDAP_DOMAIN2DN */
   }
   if (strcasecmp(value, "\"\"") == 0)
+  {
+    free(value);
     value = "";
+  }
   /* find the spot in the list of bases */
   for (i = 0; i < NSS_LDAP_CONFIG_MAX_BASES; i++)
     if (bases[i] == NULL)
@@ -845,7 +848,7 @@ static const char *print_ssl(int ssl)
   }
 }
 
-static int get_tls_reqcert(const char *filename, int lnr,
+static int get_tls_reqcertsan_value(const char *filename, int lnr,
                            const char *keyword, char **line)
 {
   char token[16];
@@ -888,7 +891,7 @@ static void handle_tls_reqcert(const char *filename, int lnr,
                                const char *keyword, char *line)
 {
   int value, rc;
-  value = get_tls_reqcert(filename, lnr, keyword, &line);
+  value = get_tls_reqcertsan_value(filename, lnr, keyword, &line);
   get_eol(filename, lnr, keyword, &line);
   log_log(LOG_DEBUG, "ldap_set_option(LDAP_OPT_X_TLS_REQUIRE_CERT,%s)",
           print_tls_reqcert(value));
@@ -900,7 +903,7 @@ static void handle_tls_reqsan(const char *filename, int lnr,
                                    const char *keyword, char *line)
 {
   int value, rc;
-  value = get_tls_reqcert(filename, lnr, keyword, &line);
+  value = get_tls_reqcertsan_value(filename, lnr, keyword, &line);
   get_eol(filename, lnr, keyword, &line);
   log_log(LOG_DEBUG, "ldap_set_option(LDAP_OPT_X_TLS_REQUIRE_SAN,%s)",
           print_tls_reqcert(value));
